==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Y0ur 5173\'5 UR1', # MODIF
	'form_pet_aucune_signature' => 'N0 51gn47ur3 m47ch35 7h15 c0d3...',
	'form_pet_confirmation' => 'P13453 c0nf1rm y0ur 51gn47ur3:',
	'form_pet_deja_signe' => 'Y0u h4v3 41r34dy 51gn3d 7h15 73x7.',
	'form_pet_envoi_mail_confirmation' => '4 c0nf1rm4710n 3-m411 h45 ju57 b33n 53n7 70 y0u. Y0u 5h0u1d v1517 7h3 UR1 m3n710n3d 1n 7h15 m411 70 v411d473 y0ur 51gn47ur3.', # MODIF
	'form_pet_mail_confirmation' => 'G00d d4y,

Y0u r3qu3573d 70 51gn 7h3 p371710n:
@titre@.

Y0u pr0v1d3d 7h3 f0110w1ng 1nf0rm4710n:
    N4m3: @nom_email@
    5173: @nom_site@ - @url_site@

1MP0R74N7...
70 v411d473 y0ur 51gn47ur3, y0u ju57 h4v3 70 c0nn3c7 70
7h3 4ddr355 b310w (07h3rw153, y0ur r3qu357
w111 b3 r3j3c73d):
    @url@

7h4nk y0u f0r y0ur p4r71c1p4710n
', # MODIF
	'form_pet_message_commentaire' => '4ny m3554g3 0r c0mm3n7?', # MODIF
	'form_pet_nom_site2' => 'N4m3 0f y0ur w3b 5173', # MODIF
	'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
	'form_pet_probleme_technique' => '73chn1c41 pr0b13m, 51gn47ur35 4r3 1n73rrup73d m0m3n74r11y.',
	'form_pet_signature_validee' => 'Y0ur 51gn47ur3 15 v411d. 17 w111 4pp34r wh3n 7h3 5173 w111 b3 upd473d. 7h4nk y0u!', # MODIF
	'form_pet_site_deja_enregistre' => '7h15 5173 15 41r34dy r3g1573r3d',
	'form_pet_url_invalide' => '7h3 UR1 7h47 y0u h4v3 3n73r3d 15 n07 v411d.',
	'form_pet_votre_email' => 'Y0ur 3-m411 4ddr355',
	'form_pet_votre_nom' => 'Y0ur n4m3 0r 41145', # MODIF
	'form_pet_votre_site' => '1f y0u h4v3 4 w3b 5173, y0u c4n 3n73r 17 b310w',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => '3-M411 4DDR355:',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Signature supprimée', # NEW
	'info_signature_supprimee_erreur' => 'Erreur : ce code de suppression ne correspond a aucune signature', # NEW
	'info_site_web' => 'W3B 5173:',
	'info_texte_message' => '73x7 0f y0ur m3554g3:',

	// L
	'lien_reponse_article' => 'R3p1y 70 7h3 4r71c13',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=en_hx
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => '4c71v471ng 7h3 p371710n',
	'bouton_radio_pas_petition' => 'N0 p371710n',
	'bouton_radio_petition_activee' => 'P371710n 4c71v473d',
	'bouton_radio_supprimer_petition' => 'D31373 7h3 p371710n',

	// F
	'form_pet_adresse_site' => 'Y0ur 5173’5 UR1', # MODIF
	'form_pet_aucune_signature' => 'N0 51gn47ur3 m47ch35 7h15 c0d3...', # MODIF
	'form_pet_confirmation' => 'P13453 c0nf1rm y0ur 51gn47ur3:',
	'form_pet_deja_signe' => 'Y0u h4v3 41r34dy 51gn3d 7h15 73x7.',
	'form_pet_envoi_mail_confirmation' => '4 c0nf1rm4710n 3-m411 h45 ju57 b33n 53n7 70 y0u. Y0u 5h0u1d v1517 7h3 UR1 m3n710n3d 1n 7h15 m411 70 v411d473 y0ur 51gn47ur3.', # MODIF
	'form_pet_mail_confirmation' => 'G00d d4y,

Y0u r3qu3573d 70 51gn 7h3 p371710n:
@titre@.

Y0u pr0v1d3d 7h3 f0110w1ng 1nf0rm4710n:
    N4m3: @nom_email@
    5173: @nom_site@ - @url_site@

1MP0R74N7...
70 v411d473 y0ur 51gn47ur3, y0u ju57 h4v3 70 c0nn3c7 70
7h3 4ddr355 b310w (07h3rw153, y0ur r3qu357
w111 b3 r3j3c73d):
    @url@

7h4nk y0u f0r y0ur p4r71c1p4710n
', # MODIF
	'form_pet_nom_site2' => 'N4m3 0f y0ur w3b 5173', # MODIF
	'form_pet_probleme_technique' => '73chn1c41 pr0b13m, 51gn47ur35 4r3 1n73rrup73d m0m3n74r11y.',
	'form_pet_signature_validee' => 'Y0ur 51gn47ur3 15 v411d. 17 w111 4pp34r wh3n 7h3 5173 w111 b3 upd473d. 7h4nk y0u!', # MODIF
	'form_pet_site_deja_enregistre' => '7h15 5173 15 41r34dy r3g1573r3d',
	'form_pet_url_invalide' => '7h3 UR1 7h47 y0u h4v3 3n73r3d 15 n07 v411d.',
	'form_pet_votre_email' => 'Y0ur 3-m411 4ddr355',
	'form_pet_votre_nom' => 'Y0ur n4m3 0r 41145', # MODIF
	'form_pet_votre_site' => '1f y0u h4v3 4 w3b 5173, y0u c4n 3n73r 17 b310w',

	// I
	'info_adresse_email' => '3-M411 4DDR355:',
	'info_site_web' => 'W3B 5173:',

	// L
	'lien_reponse_article' => 'R3p1y 70 7h3 4r71c13'
);

?>
